@@ -462,7 +462,7 @@ int kval;
     /* locate this byte in the tree */
     code = -1;
     for (i = 0 ; i < knode->keylist_len ; ++i) {
-	if (knode->kval[i] == kval) {
+	if (knode->kval[i] == (char)kval) {
 	    knode = knode->knext[i];
 	    code = knode->kcode;
 	    break;
