@@ -49,7 +49,7 @@ extern time_t	  time();
 #define FEB		 1	/* 0 = January 		  */
 #define DAYS_IN_LEAP_FEB 29	/* leap year only 	  */
 
-#define leapyear(year)	((year % 4 == 0) && ((year % 100 != 0) || (year % 400 == 0)))
+#define leapyear(year)  (((year) % 4 == 0) && (((year) % 100 != 0) || ((year) % 400 == 0)) )
 
 int  days_in_month[] = { 31,    28,    31,    30,    31,     30, 
 		  31,     31,    30,   31,    30,     31,  -1};
