@@ -301,7 +301,7 @@ int add_new_only;
 #endif /* MMDF */
 
 	if (curr_folder.flags & FOLDER_IS_SPOOL) {
-	  lock(LOCK_INCOMING);	/* ensure no mail arrives while we do this! */
+	  elm_lock(LOCK_INCOMING);	/* ensure no mail arrives while we do this! */
 	  if (! add_new_only) {
 	    if (elm_access(curr_folder.tempname, ACCESS_EXISTS) == 0) {
 	      /* Hey!  What the hell is this?  The temp file already exists? */
@@ -389,7 +389,7 @@ int add_new_only;
 	fflush(curr_folder.fp);
 	curr_folder.size = bytes(curr_folder.filename);
         if (!(curr_folder.flags & FOLDER_IS_SPOOL)) 
-   	   unlock();
+   	   elm_unlock();
 
 	/** now let's copy it all across accordingly... **/
 
@@ -873,7 +873,7 @@ int add_new_only;
 
 	if (curr_folder.flags & FOLDER_IS_SPOOL) {
 	  fflush (curr_folder.fp);
-	  unlock();	/* remove lock file! */
+	  elm_unlock();	/* remove lock file! */
 	  if ((ferror(curr_folder.fp)) || (fclose(curr_folder.fp) == EOF)) {
 	    ShutdownTerm();
 	    error2(catgets(elm_msg_cat, ElmSet, ElmCloseOnFolderFailed,
