@@ -186,10 +186,14 @@ int msg;
     /* don't quote already-quoted name */
     q = (from_buf[0] == '"' ? "" : "\"");
 
-    sprintf(shdr->in_reply_to, "%s from %s%s%s at %s",
+/*    sprintf(shdr->in_reply_to, "%s from %s%s%s at %s",
 	(*hdr->messageid ? hdr->messageid : "<no.id>"),
 	q, from_buf, q,
-	elm_date_str(date_buf, hdr, TRUE));
+	elm_date_str(date_buf, hdr, TRUE)); */
+   
+   sprintf(shdr->in_reply_to, "%s", 
+	    (*hdr->messageid ? hdr->messageid : "<no.id>"));
+   
 }
 
 
